# bankroll-model [![PyPI version](https://badge.fury.io/py/bankroll-model.svg)](https://badge.fury.io/py/bankroll-model) [![CircleCI](https://circleci.com/gh/bankroll-py/bankroll-model.svg?style=svg&circle-token=d21e7621caaa262910dfdd209c116533c49db8b2)](https://circleci.com/gh/bankroll-py/bankroll-model)

This library implements brokerage-agnostic model objects for investment and trading data. Among other benefits, this permits "the same" instruments to be compared _across_ multiple brokers, including positions and trades that span multiple brokers.

This library is part of the [bankroll](https://github.com/bankroll-py) project.
